summaryrefslogtreecommitdiffstats
path: root/kchart/kchart_view.cc
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-02-01 15:02:43 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-02-01 15:02:43 -0600
commitaea627236e4de24599c3e30617cf264c3c1b7d40 (patch)
tree467e13ca5a7eb0ab292259289ecc3572f53c5eae /kchart/kchart_view.cc
parent786304c6211f35ddc4cdd54b7aa7985fef4a2e70 (diff)
downloadkoffice-aea627236e4de24599c3e30617cf264c3c1b7d40.tar.gz
koffice-aea627236e4de24599c3e30617cf264c3c1b7d40.zip
Rename a number of classes to enhance compatibility with KDE4
Diffstat (limited to 'kchart/kchart_view.cc')
-rw-r--r--kchart/kchart_view.cc48
1 files changed, 24 insertions, 24 deletions
diff --git a/kchart/kchart_view.cc b/kchart/kchart_view.cc
index 00606e81..62fd3825 100644
--- a/kchart/kchart_view.cc
+++ b/kchart/kchart_view.cc
@@ -64,100 +64,100 @@ KChartView::KChartView( KChartPart* part, TQWidget* parent, const char* name )
m_dcop = 0;
dcopObject(); // build it
- m_importData = new KAction( i18n( "Import Data..." ), 0,
+ m_importData = new TDEAction( i18n( "Import Data..." ), 0,
TQT_TQOBJECT(this), TQT_SLOT( importData() ),
actionCollection(), "import_data" );
#if 0
- KAction * actionExtraCreateTemplate =
+ TDEAction * actionExtraCreateTemplate =
#endif
- new KAction( i18n( "&Create Template From Document..." ), 0,
+ new TDEAction( i18n( "&Create Template From Document..." ), 0,
TQT_TQOBJECT(this), TQT_SLOT( extraCreateTemplate() ),
actionCollection(), "extra_template" );
- m_wizard = new KAction( i18n("Customize with &Wizard..."),
+ m_wizard = new TDEAction( i18n("Customize with &Wizard..."),
"wizard", 0,
TQT_TQOBJECT(this), TQT_SLOT( wizard() ),
actionCollection(), "wizard");
- m_edit = new KAction( i18n("Edit &Data..."), "edit", 0,
+ m_edit = new TDEAction( i18n("Edit &Data..."), "edit", 0,
TQT_TQOBJECT(this), TQT_SLOT( editData() ),
actionCollection(), "editdata");
- m_config = new KAction( i18n( "&Chart..." ), "configure", 0,
+ m_config = new TDEAction( i18n( "&Chart..." ), "configure", 0,
TQT_TQOBJECT(this), TQT_SLOT( slotConfig() ),
actionCollection(), "config" );
- // One KToggleAction per chart type
- m_chartbars = new KToggleAction( i18n("&Bar"), "chart_bar_3d", 0, TQT_TQOBJECT(this),
+ // One TDEToggleAction per chart type
+ m_chartbars = new TDEToggleAction( i18n("&Bar"), "chart_bar_3d", 0, TQT_TQOBJECT(this),
TQT_SLOT( barsChart() ), actionCollection(),
"barschart");
m_chartbars->setExclusiveGroup( "charttypes" );
m_chartbars->setChecked( true );
- m_chartline = new KToggleAction( i18n("&Line"), "chart_line", 0, TQT_TQOBJECT(this),
+ m_chartline = new TDEToggleAction( i18n("&Line"), "chart_line", 0, TQT_TQOBJECT(this),
TQT_SLOT( lineChart() ), actionCollection(),
"linechart");
m_chartline->setExclusiveGroup( "charttypes" );
- m_chartareas = new KToggleAction( i18n("&Area"), "chart_area", 0, TQT_TQOBJECT(this),
+ m_chartareas = new TDEToggleAction( i18n("&Area"), "chart_area", 0, TQT_TQOBJECT(this),
TQT_SLOT( areasChart() ), actionCollection(),
"areaschart");
m_chartareas->setExclusiveGroup( "charttypes" );
- m_charthilo = new KToggleAction( i18n("&HiLo"), "chart_hilo", 0, TQT_TQOBJECT(this),
+ m_charthilo = new TDEToggleAction( i18n("&HiLo"), "chart_hilo", 0, TQT_TQOBJECT(this),
TQT_SLOT( hiLoChart() ), actionCollection(),
"hilochart");
m_charthilo->setExclusiveGroup( "charttypes" );
- m_chartbw = new KToggleAction( i18n("Bo&x && Whiskers"), "chart_boxwhisker", 0, TQT_TQOBJECT(this),
+ m_chartbw = new TDEToggleAction( i18n("Bo&x && Whiskers"), "chart_boxwhisker", 0, TQT_TQOBJECT(this),
TQT_SLOT( bwChart() ), actionCollection(),
"bwchart");
m_chartbw->setExclusiveGroup( "charttypes" );
- m_chartpie = new KToggleAction( i18n("&Pie"), "chart_pie", 0, TQT_TQOBJECT(this),
+ m_chartpie = new TDEToggleAction( i18n("&Pie"), "chart_pie", 0, TQT_TQOBJECT(this),
TQT_SLOT( pieChart() ), actionCollection(),
"piechart");
m_chartpie->setExclusiveGroup( "charttypes" );
- m_chartring = new KToggleAction( i18n("&Ring"), "chart_ring", 0, TQT_TQOBJECT(this),
+ m_chartring = new TDEToggleAction( i18n("&Ring"), "chart_ring", 0, TQT_TQOBJECT(this),
TQT_SLOT( ringChart() ), actionCollection(),
"ringchart");
m_chartring->setExclusiveGroup( "charttypes" );
- m_chartpolar = new KToggleAction( i18n("&Polar"), "chart_polar", 0, TQT_TQOBJECT(this),
+ m_chartpolar = new TDEToggleAction( i18n("&Polar"), "chart_polar", 0, TQT_TQOBJECT(this),
TQT_SLOT( polarChart() ), actionCollection(),
"polarchart");
m_chartpolar->setExclusiveGroup( "charttypes" );
- // Configuration KActions
- m_colorConfig = new KAction( i18n( "&Colors..." ), 0,
+ // Configuration TDEActions
+ m_colorConfig = new TDEAction( i18n( "&Colors..." ), 0,
TQT_TQOBJECT(this), TQT_SLOT( slotConfigColor() ),
actionCollection(), "color_config" );
- m_fontConfig = new KAction( i18n( "&Font..." ), 0,
+ m_fontConfig = new TDEAction( i18n( "&Font..." ), 0,
TQT_TQOBJECT(this), TQT_SLOT( slotConfigFont() ),
actionCollection(), "font_config" );
- m_backConfig = new KAction( i18n( "&Background..." ), 0,
+ m_backConfig = new TDEAction( i18n( "&Background..." ), 0,
TQT_TQOBJECT(this), TQT_SLOT( slotConfigBack() ),
actionCollection(), "back_config" );
- m_legendConfig = new KAction( i18n( "&Legend..." ), 0,
+ m_legendConfig = new TDEAction( i18n( "&Legend..." ), 0,
TQT_TQOBJECT(this), TQT_SLOT( slotConfigLegend() ),
actionCollection(), "legend_config" );
- m_subTypeChartConfig = new KAction( i18n( "Chart &Sub-type..." ), 0,
+ m_subTypeChartConfig = new TDEAction( i18n( "Chart &Sub-type..." ), 0,
TQT_TQOBJECT(this), TQT_SLOT( slotConfigSubTypeChart() ),
actionCollection(), "legend_subtype" );
- m_dataFormatConfig = new KAction( i18n( "&Data Format..." ), 0,
+ m_dataFormatConfig = new TDEAction( i18n( "&Data Format..." ), 0,
TQT_TQOBJECT(this), TQT_SLOT( slotConfigDataFormat() ),
actionCollection(), "data_format" );
- m_headerFooterConfig = new KAction( i18n( "&Header && Footer..." ), 0,
+ m_headerFooterConfig = new TDEAction( i18n( "&Header && Footer..." ), 0,
TQT_TQOBJECT(this), TQT_SLOT( slotConfigHeaderFooterChart() ),
actionCollection(), "headerfooter_subtype" );
- m_pageLayoutConfig = new KAction( i18n( "Page Layout..." ), 0,
+ m_pageLayoutConfig = new TDEAction( i18n( "Page Layout..." ), 0,
TQT_TQOBJECT(this), TQT_SLOT( slotConfigPageLayout() ),
actionCollection(), "page_layout" );